@@ -1,28 +1,29 @@
-from dataclasses import dataclass, field
 from abc import abstractmethod
-from solana.transaction import Signature
-from solana.rpc.commitment import Commitment
+from dataclasses import dataclass, field
+from typing import Callable, Literal, Union, Optional
+
 from solana.rpc.async_api import AsyncClient
-
-from typing import Callable, Literal, Union
-
+from solana.rpc.commitment import Commitment
 from solders.pubkey import Pubkey
 
 from driftpy.constants.config import DRIFT_PROGRAM_ID
+from driftpy.events.grpc_log_provider import GrpcLogProvider
 from driftpy.types import (
-    NewUserRecord,
-    DepositRecord,
-    SpotInterestRecord,
     CurveRecord,
+    DepositRecord,
+    FundingPaymentRecord,
+    FundingRateRecord,
+    GrpcLogProviderConfig,
     InsuranceFundRecord,
     InsuranceFundStakeRecord,
-    LPRecord,
-    FundingRateRecord,
-    FundingPaymentRecord,
     LiquidationRecord,
-    SettlePnlRecord,
-    OrderRecord,
+    LogProviderCallback,
+    LPRecord,
+    NewUserRecord,
     OrderActionRecord,
+    OrderRecord,
+    SettlePnlRecord,
+    SpotInterestRecord,
     SwapRecord,
 )
 
@@ -41,6 +42,11 @@ EventType = Literal[
     "OrderRecord",
     "OrderActionRecord",
     "SwapRecord",
+    "SpotMarketVaultDepositRecord",
+    "SignedMsgOrderRecord",
+    "DeleteUserRecord",
+    "FuelSweepRecord",
+    "FuelSeasonRecord",
 ]
 
 Event = Union[
@@ -62,10 +68,9 @@ Event = Union[
 
 
 @dataclass
-# type: ignore
 class WrappedEvent:
     event_type: EventType
-    tx_sig: Signature
+    tx_sig: any
     slot: int
     tx_sig_index: int
     data: Event
@@ -73,7 +78,7 @@ class WrappedEvent:
 
 SortFn = Callable[[WrappedEvent, WrappedEvent], int]
 
-EventSubscriptionOrderBy = Union["blockchain", "client"]
+EventSubscriptionOrderBy = Literal["blockchain", "client"]
 Asc = Literal["asc"]
 Desc = Literal["desc"]
 EventSubscriptionOrderDirection = Union[Asc, Desc]
@@ -87,12 +92,12 @@ class WebsocketLogProviderConfig:
 @dataclass
 class PollingLogProviderConfig:
     frequency: float = 1
-    batch_size: int = None
+    batch_size: Optional[int] = None
 
 
-LogProviderConfig = Union[WebsocketLogProviderConfig, PollingLogProviderConfig]
-
-LogProviderCallback = Callable[[Signature, int, list[str]], None]
+LogProviderConfig = Union[
+    WebsocketLogProviderConfig, PollingLogProviderConfig, GrpcLogProviderConfig
+]
 
 
 class LogProvider:
@@ -127,6 +132,11 @@ DEFAULT_EVENT_TYPES = (
     "OrderRecord",
     "OrderActionRecord",
     "SwapRecord",
+    "SpotMarketVaultDepositRecord",
+    "SignedMsgOrderRecord",
+    "DeleteUserRecord",
+    "FuelSweepRecord",
+    "FuelSeasonRecord",
 )
 
 
@@ -142,7 +152,7 @@ class EventSubscriptionOptions:
     log_provider_config: LogProviderConfig = field(
         default_factory=WebsocketLogProviderConfig
     )
-    until_tx: Signature = None
+    until_tx: any = None
 
     @staticmethod
     def default():
@@ -153,6 +163,14 @@ class EventSubscriptionOptions:
             from driftpy.events.websocket_log_provider import WebsocketLogProvider
 
             return WebsocketLogProvider(connection, self.address, self.commitment)
+
+        elif isinstance(self.log_provider_config, GrpcLogProviderConfig):
+            return GrpcLogProvider(
+                self.log_provider_config,
+                commitment=self.commitment,
+                user_account_to_filter=self.user_account_to_filter,
+            )
+
         else:
             if (
                 str(self.commitment) != "confirmed"
